@@ -13,15 +13,14 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
 """Utilities for getting the location of various directories.
 
 Enables identical use for installed and uninstalled versions.
 """
 
 import os.path
+from gi.repository import GLib
 
 
 # Again, mostly the same thing as in bin/pitivi.in and pitivi/utils/misc.py:
@@ -33,10 +32,11 @@ def in_devel():
     """Returns whether the app is run from a git checkout."""
     return os.environ.get("PITIVI_DEVELOPMENT", "0") != "0"
 
+
 LIBDIR = '/usr/lib'
 PKGDATADIR = '/usr/share/pitivi'
 GITVERSION = ''
-VERSION = '0.999'
+VERSION = '2020.09.1'
 APPNAME = 'Pitivi'
 APPURL = 'http://www.pitivi.org/'
 RELEASES_URL = 'http://pitivi.org/releases.txt'
@@ -80,6 +80,18 @@ def get_videopresets_dir():
     """Returns our directory with Video Presets files."""
     return os.path.join(get_data_dir(), 'videopresets')
 
+
 def get_gstpresets_dir():
     """Returns our directory with Gst Presets files."""
     return os.path.join(get_data_dir(), 'gstpresets')
+
+
+def get_plugins_dir():
+    """Returns our default directory to store official plugins."""
+    return os.path.join(_get_root_dir(), 'plugins')
+
+
+def get_user_plugins_dir():
+    """Returns our default directory to store non-official plugins."""
+    user_data_dir = GLib.get_user_data_dir()
+    return os.path.join(user_data_dir, 'pitivi', 'plugins')
